/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.junit.Test;

/**
 * Unit test about the legal information that the archive must contain
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class LegalIT extends AbstractIT {

    /**
     * <p>
     * Verify that a file 'LICENSE' exists.
     * </p>
     */
    @Test
    public void licenseFile() throws IOException {
        
        final File licenseFile = new File(ARCHIVE_BASE_DIRECTORY, "LICENSE");
        assertTrue("'LICENSE' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, licenseFile));
        final long fileSize = FileUtils.sizeOf(licenseFile);
        assertTrue("Too short file 'LICENSE', " + fileSize + " bytes.", fileSize > 20000);
    }

    /**
     * <p>
     * Verify that a file 'THIRD-PARTY' exists.
     * </p>
     */
    @Test
    public void thirdPartyFile() throws IOException {

        final File thirdPartyFile = new File(ARCHIVE_BASE_DIRECTORY, "THIRD-PARTY");
        assertTrue("'THIRD-PARTY' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, thirdPartyFile));
        final long fileSize = FileUtils.sizeOf(thirdPartyFile);
        assertTrue("Too short file 'THIRD-PARTY', " + fileSize + " bytes.", fileSize > 7500);
        assertTrue("Too long file 'THIRD-PARTY', " + fileSize + " bytes.", fileSize < 8500);
    }

    /**
     * <p>
     * Verify that license files of third party are packaged.
     * </p>
     */
    @Test
    public void thirdPartyLicenseFiles() throws IOException {

        final File thirdPartyLIcenseFiles = new File(ARCHIVE_BASE_DIRECTORY, "licenses");
        assertTrue("3PP licenses missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, thirdPartyLIcenseFiles));
        assertTrue("Not enough different 3PP licenses", thirdPartyLIcenseFiles.listFiles().length > 7);
        assertTrue("Too many different 3PP licenses ", thirdPartyLIcenseFiles.listFiles().length < 15);
    }

    /**
     * <p>
     * Verify that a file 'COPYRIGHT' exists.
     * </p>
     */
    @Test
    public void copyrightFile() throws IOException {

        final File copyrightFile = new File(ARCHIVE_BASE_DIRECTORY, "COPYRIGHT");
        assertTrue("'COPYRIGHT' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, copyrightFile));
        final long fileSize = FileUtils.sizeOf(copyrightFile);
        assertTrue("Too short file 'COPYRIGHT', " + fileSize + " bytes.", fileSize > 500);
        assertTrue("Too long file 'COPYRIGHT', " + fileSize + " bytes.", fileSize < 1000);
    }

}
