#!/bin/sh
#
# Copyright (c) 2010-2012 EBM WebSourcing, 2012-2017 Linagora
#
# This program/library is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# This program/library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program/library; If not, see http://www.gnu.org/licenses/
# for the GNU Lesser General Public License version 2.1.
#
#############################################################################
#
#                      Petals CLI Bootstrap Script
#
# Environment variables:
#
#	JAVA_HOME	Directory containing the JRE. Use the java executable
#			found in $PATH if not defined.
#
#	JAVA_OPTS	Options for the JVM. Try "java -h" to get informations
#			about the available options for your environment
#
#############################################################################

# Extra checks
set -eu

#Test symbolic link 
if [ -h $0 ];then
	CUR_DIR=$(dirname $(readlink $0))
else
	CUR_DIR=`dirname $0`
fi

if [ -z "${JAVA_OPTS:-}" ]; then
   JAVA_OPTS=""
fi

# Set the path to the java executable
JAVA="${JAVA_HOME:-}/bin/java"
[ -x "$JAVA" ] || JAVA="`which java`" || {
	echo "ERROR: java executable not found" >&2
	exit 1
}


# Set the path to bootstrap jar
PETALS_CLI_JAR="${CUR_DIR}/../lib/petals-cli.jar"
[ -f "$PETALS_CLI_JAR" ] || {
	echo "ERROR: petals-cli.jar: the jar archive was not found" >&2
	exit 1
}

# Add cli, extensions and default preferences file to the classpath
PETALS_CLI_CLASSPATH="$PETALS_CLI_JAR:$CUR_DIR/../conf:$CUR_DIR/../extensions/*"

# Adapt patches if the architecture is Cygwin
case "`uname`" in
	CYGWIN*)
		JAVA="`cygpath --unix "$JAVA"`"
		PETALS_CLI_CLASSPATH="`cygpath --path --windows "$PETALS_CLI_CLASSPATH"`"
		;;
esac

# Set an potential user preference file
USER_PREFS=$HOME/.petals-cli/petals-cli.default
if [ -f "$USER_PREFS" ];
then
   # A user preference file exists, it is used.
   export PETALS_CLI_PREFS="$USER_PREFS"
fi

# Start
exec "$JAVA" -classpath $PETALS_CLI_CLASSPATH $JAVA_OPTS -Djline.shutdownhook=true -Djava.protocol.handler.pkgs=org.ops4j.pax.url org.ow2.petals.cli.Main "$@"
