/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.http;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.io.IOUtils;

/**
 * @author Christophe DENEUX - Linagora
 */
public class DownloadingArtifactServlet extends HttpServlet {
    
    private static final long serialVersionUID = -2098344570982536519L;

    private final URL artifactUrl;
    
    public DownloadingArtifactServlet(final URL artifactUrl) {
        this.artifactUrl = artifactUrl;
    }

    private void setsHeaderAndDateHeaderInResponse(final HttpServletResponse resp) {
        resp.setHeader("Cache-Control", "no-cache"); // HTTP 1.1
        resp.setHeader("Pragma", "no-cache"); // HTTP 1.0
        resp.setDateHeader("Expires", 0); // prevents caching at the proxy
    }

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {

        this.setsHeaderAndDateHeaderInResponse(resp);
        resp.setContentType("application/zip");

        final OutputStream output = resp.getOutputStream();
        final InputStream inputStream = this.artifactUrl.openStream();
        try {
            IOUtils.copy(inputStream, output);

            output.flush();
        } catch (Exception e) {
            throw new ServletException("Can't read file content", e);
        } finally {
            output.close();
            inputStream.close();
        }
    }
}
