/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import org.ow2.petals.admin.api.PetalsAdministration;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;
import org.ow2.petals.admin.api.exception.NoConnectionException;
import org.ow2.petals.cli.api.command.CommandUtil;
import org.ow2.petals.cli.api.command.DisconnectionCommand;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;
import org.ow2.petals.cli.api.command.exception.DisconnectionErrorException;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class Disconnect extends AbstractPetalsCliCommand implements DisconnectionCommand {

    public Disconnect() {
        super();
        this.setUsage(CommandUtil.formatCommandUsage(this));
        this.setDescription("Disconnect from a petals container");
    }

    @Override
    public void doExecute(final String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 0)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        this.disconnect();
        this.getShell().setDefaultPrompt();

    }

    @Override
    public void disconnect() throws DisconnectionErrorException, CommandException {

        try {
            final PetalsAdministration containerAdministration = getAdmin();
            containerAdministration.disconnect();
            this.getShell().onDisconnection();
        } catch (final DuplicatedServiceException e) {
            throw new DisconnectionErrorException(this, e);
        } catch (final MissingServiceException e) {
            throw new DisconnectionErrorException(this, e);
        } catch (final NoConnectionException e) {
            // NOP: No connection previously established
        } catch (final ContainerAdministrationException e) {
            throw new DisconnectionErrorException(this, e);
        }
    }

    @Override
    public boolean isConnected() throws DisconnectionErrorException {
        try {
            final PetalsAdministration containerAdministration = getAdmin();
            return containerAdministration.isConnected();
        } catch (final DuplicatedServiceException e) {
            throw new DisconnectionErrorException(this, e);
        } catch (final MissingServiceException e) {
            throw new DisconnectionErrorException(this, e);
        } catch (final ContainerAdministrationException e) {
            throw new DisconnectionErrorException(this, e);
        }
    }

}