/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import java.util.Map.Entry;
import java.util.Properties;

import org.ow2.petals.admin.api.ContainerAdministration;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class PropertiesList extends AbstractPetalsCliCommand {

    public PropertiesList() {
        super("properties-list");
        this.setUsage("usage: properties-list");
        this.setDescription("Get the values defined in its server.properties file");
    }

    @Override
    public void doExecute(final String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 0)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        try {
            final ContainerAdministration containerAdministration = getAdmin().newContainerAdministration();
            final Properties serverProperties = containerAdministration.getServerProperties();
            for (final Entry<Object, Object> property : serverProperties.entrySet()) {
                final String key = (String) property.getKey();
                final String value = (String) property.getValue();
                this.getShell().getPrintStream()
                        .println(String.format("%s: %s", key, value.isEmpty() ? "\"\"" : value));
            }
        } catch (final DuplicatedServiceException e) {
            throw new CommandException(this, e);
        } catch (final MissingServiceException e) {
            throw new CommandException(this, e);
        } catch (final Exception e) {
            throw new CommandException(this, e);
        }
    }

}
