/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.hamcrest.Matchers.containsString;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.ow2.petals.cli.AbstractCliTest;
import org.ow2.petals.cli.Main;
import org.ow2.petals.cli.base.junit.shell.PetalsInteractiveCliUtils;
import org.ow2.petals.cli.command.Exit;
import org.ow2.petals.cli.shell.ShellFactory;
import org.ow2.petals.cli.shell.extension.PetalsAdminShellExtension;
/**
 * Unit test of {@link Exit}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ExitTest extends AbstractCliTest {

    /**
     * Test that the command usage is defined
     */
    @Test
    public void testUsage_0() {
        final ListArtifacts command = new ListArtifacts();
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage", usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage", usage.contains(command.getName()));
    }

    /**
     * Test of the command "exit", where:
     * <ul>
     * <li>a connection is previously established,</li>
     * <li>no argument is provided.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>the connection is established before to execute 'exit',</li></li>the connection is released after 'exit' when
     * the shell ends,</li>
     * </ul>
     * </p>
     */
    @Test()
    public void testArguments_1() throws Exception {


        try {
            // Enable the hack for Windows?
            PetalsInteractiveCliUtils.hackForWindows(true);

            final String hostname = "localhost";
            
            PetalsAdminShellExtension admin = runCli(createBasicPreferences(hostname, 7700, "petals", "petals", null),
                    "-" + ShellFactory.CONSOLE_SHORT_OPTION);

            // Wait that Petals CLI starts
            checkOut(containsString(Main.PROMPT_BASE + ">"));

            // Connect
            systemIn.writeLine("connect");

            // Wait the execution of the command
            checkOut(containsString("Would you like to connect to petals:*****@localhost:7700? (y/n)"));

            // Confirmation
            systemIn.writeLine("y");

            // Wait the execution of the confirmation
            checkOut(containsString("petals-cli@" + hostname + ":7700>"));
            assertTrue("Connection not established", admin.getAdmin().isConnected());

            // Enter the command
            systemIn.writeLine("exit");

            waitThreadOrFail();

            assertFalse("Connection not disconnected", admin.getAdmin().isConnected());

        } finally {
            // Disable the hack for Windows
            PetalsInteractiveCliUtils.hackForWindows(false);
        }
    }


}
