/**
 * Copyright (c) 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import org.junit.Test;
import org.ow2.petals.cli.api.command.Command;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;
import org.ow2.petals.cli.api.command.exception.ConnectionRequiredException;
import org.ow2.petals.cli.base.junit.shell.StringStreamShell;

/**
 * Unit test of {@link PropertiesList}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PropertiesListTest extends AbstractConnectedShellTest {

    /**
     * Test that the command usage is defined
     */
    @Test
    public void testUsage_0() {
        final PropertiesList command = new PropertiesList();
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage",
                usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage",
                usage.contains(command.getName()));
    }

    /**
     * Test of the command "properties-list" against argument management, where:
     * <ul>
     * <li>an argument is provided.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: an error occurs about bad argument number
     * </p>
     */
    @Test
    public void testArgumentsError_0() throws CommandException {

        final PropertiesList command = new PropertiesList();
        command.setShell(this.dummyShellWrapper.getShell());
        try {
            command.execute(new String[] { "-z" });
            fail("CommandBadArgumentNumberException is not thrown");
        } catch (final CommandTooManyArgumentsException e) {
            assertTrue("Error label is missing.",
                    e.getMessage().startsWith(CommandTooManyArgumentsException.TOO_MANY_ARGUMENTS));
        }
    }

    /**
     * <p>
     * Test of the command "properties-list" when no connection is established to run the command.
     * </p>
     * <p>
     * Expected results: an error occurs about the connection not established.
     * </p>
     */
    @Test(expected = ConnectionRequiredException.class)
    public void executeNotConnected() throws CommandException {

        final StringStreamShell shell = new StringStreamShell();
        final Command command = new PropertiesList();
        command.setShell(shell);

        command.execute(new String[] {});
    }
}
